@@ -1,4 +1,4 @@
-# Copyright 2020 Amazon.com, Inc. or its affiliates. All Rights Reserved.
+# Copyright Amazon.com, Inc. or its affiliates. All Rights Reserved.
 #
 # Licensed under the Apache License, Version 2.0 (the "License"). You
 # may not use this file except in compliance with the License. A copy of
@@ -733,9 +733,9 @@ class PySparkProcessor(_SparkProcessorBase):
     ):
         """Returns a RunArgs object.
 
-        This object contains the normalized inputs, outputs
-            and arguments needed when using a ``PySparkProcessor``
-            in a :class:`~sagemaker.workflow.steps.ProcessingStep`.
+        This object contains the normalized inputs, outputs and arguments
+        needed when using a ``PySparkProcessor`` in a
+        :class:`~sagemaker.workflow.steps.ProcessingStep`.
 
         Args:
             submit_app (str): Path (local or S3) to Python file to submit to Spark
@@ -982,9 +982,9 @@ class SparkJarProcessor(_SparkProcessorBase):
     ):
         """Returns a RunArgs object.
 
-        This object contains the normalized inputs, outputs
-            and arguments needed when using a ``SparkJarProcessor``
-            in a :class:`~sagemaker.workflow.steps.ProcessingStep`.
+        This object contains the normalized inputs, outputs and arguments
+        needed when using a ``SparkJarProcessor`` in a
+        :class:`~sagemaker.workflow.steps.ProcessingStep`.
 
         Args:
             submit_app (str): Path (local or S3) to Python file to submit to Spark
