@@ -17,7 +17,14 @@ from typing import List, Union
 
 import attr
 
+from sagemaker.deprecations import deprecated_class
 from sagemaker.workflow.conditions import Condition
+from sagemaker.workflow.steps import (
+    Step,
+    StepTypeEnum,
+)
+from sagemaker.workflow.step_collections import StepCollection
+from sagemaker.workflow.utilities import list_to_request
 from sagemaker.workflow.entities import (
     Expression,
     RequestType,
@@ -26,12 +33,6 @@ from sagemaker.workflow.properties import (
     Properties,
     PropertyFile,
 )
-from sagemaker.workflow.steps import (
-    Step,
-    StepTypeEnum,
-)
-from sagemaker.workflow.step_collections import StepCollection
-from sagemaker.workflow.utilities import list_to_request
 
 
 class ConditionStep(Step):
@@ -40,7 +41,7 @@ class ConditionStep(Step):
     def __init__(
         self,
         name: str,
-        depends_on: List[str] = None,
+        depends_on: Union[List[str], List[Step]] = None,
         conditions: List[Condition] = None,
         if_steps: List[Union[Step, StepCollection]] = None,
         else_steps: List[Union[Step, StepCollection]] = None,
@@ -114,3 +115,6 @@ class JsonGet(Expression):
                 "Path": self.json_path,
             }
         }
+
+
+JsonGet = deprecated_class(JsonGet, "JsonGet")
