@@ -54,6 +54,7 @@ class StepTypeEnum(Enum, metaclass=DefaultEnumMeta):
     TRANSFORM = "Transform"
     CALLBACK = "Callback"
     TUNING = "Tuning"
+    LAMBDA = "Lambda"
 
 
 @attr.s
@@ -63,12 +64,13 @@ class Step(Entity):
     Attributes:
         name (str): The name of the step.
         step_type (StepTypeEnum): The type of the step.
-        depends_on (List[str]): The list of step names the current step depends on
+        depends_on (List[str] or List[Step]): The list of step names or step
+            instances the current step depends on
     """
 
     name: str = attr.ib(factory=str)
     step_type: StepTypeEnum = attr.ib(factory=StepTypeEnum.factory)
-    depends_on: List[str] = attr.ib(default=None)
+    depends_on: Union[List[str], List["Step"]] = attr.ib(default=None)
 
     @property
     @abc.abstractmethod
@@ -88,11 +90,13 @@ class Step(Entity):
             "Arguments": self.arguments,
         }
         if self.depends_on:
-            request_dict["DependsOn"] = self.depends_on
+            request_dict["DependsOn"] = self._resolve_depends_on(self.depends_on)
+
         return request_dict
 
-    def add_depends_on(self, step_names: List[str]):
-        """Add step names to the current step depends on list"""
+    def add_depends_on(self, step_names: Union[List[str], List["Step"]]):
+        """Add step names or step instances to the current step depends on list"""
+
         if not step_names:
             return
 
@@ -105,6 +109,19 @@ class Step(Entity):
         """Gets a reference dict for steps"""
         return {"Name": self.name}
 
+    @staticmethod
+    def _resolve_depends_on(depends_on_list: Union[List[str], List["Step"]]):
+        """Resolver the step depends on list"""
+        depends_on = []
+        for step in depends_on_list:
+            if isinstance(step, Step):
+                depends_on.append(step.name)
+            elif isinstance(step, str):
+                depends_on.append(step)
+            else:
+                raise ValueError(f"Invalid input step name: {step}")
+        return depends_on
+
 
 @attr.s
 class CacheConfig:
@@ -153,7 +170,7 @@ class TrainingStep(Step):
         estimator: EstimatorBase,
         inputs: Union[TrainingInput, dict, str, FileSystemInput] = None,
         cache_config: CacheConfig = None,
-        depends_on: List[str] = None,
+        depends_on: Union[List[str], List[Step]] = None,
     ):
         """Construct a TrainingStep, given an `EstimatorBase` instance.
 
@@ -180,8 +197,8 @@ class TrainingStep(Step):
                   the path to the training dataset.
 
             cache_config (CacheConfig):  A `sagemaker.workflow.steps.CacheConfig` instance.
-            depends_on (List[str]): A list of step names this `sagemaker.workflow.steps.TrainingStep`
-                depends on
+            depends_on (List[str] or List[Step]): A list of step names or step instances
+                this `sagemaker.workflow.steps.TrainingStep` depends on
         """
         super(TrainingStep, self).__init__(name, StepTypeEnum.TRAINING, depends_on)
         self.estimator = estimator
@@ -226,7 +243,11 @@ class CreateModelStep(Step):
     """CreateModel step for workflow."""
 
     def __init__(
-        self, name: str, model: Model, inputs: CreateModelInput, depends_on: List[str] = None
+        self,
+        name: str,
+        model: Model,
+        inputs: CreateModelInput,
+        depends_on: Union[List[str], List[Step]] = None,
     ):
         """Construct a CreateModelStep, given an `sagemaker.model.Model` instance.
 
@@ -238,8 +259,8 @@ class CreateModelStep(Step):
             model (Model): A `sagemaker.model.Model` instance.
             inputs (CreateModelInput): A `sagemaker.inputs.CreateModelInput` instance.
                 Defaults to `None`.
-            depends_on (List[str]): A list of step names this `sagemaker.workflow.steps.CreateModelStep`
-                depends on
+            depends_on (List[str] or List[Step]): A list of step names or step instances
+                this `sagemaker.workflow.steps.CreateModelStep` depends on
         """
         super(CreateModelStep, self).__init__(name, StepTypeEnum.CREATE_MODEL, depends_on)
         self.model = model
@@ -284,7 +305,7 @@ class TransformStep(Step):
         transformer: Transformer,
         inputs: TransformInput,
         cache_config: CacheConfig = None,
-        depends_on: List[str] = None,
+        depends_on: Union[List[str], List[Step]] = None,
     ):
         """Constructs a TransformStep, given an `Transformer` instance.
 
@@ -296,8 +317,8 @@ class TransformStep(Step):
             transformer (Transformer): A `sagemaker.transformer.Transformer` instance.
             inputs (TransformInput): A `sagemaker.inputs.TransformInput` instance.
             cache_config (CacheConfig):  A `sagemaker.workflow.steps.CacheConfig` instance.
-            depends_on (List[str]): A list of step names this `sagemaker.workflow.steps.TransformStep`
-                depends on
+            depends_on (List[str] or List[Step]): A list of step names or step instances
+                this `sagemaker.workflow.steps.TransformStep` depends on
         """
         super(TransformStep, self).__init__(name, StepTypeEnum.TRANSFORM, depends_on)
         self.transformer = transformer
@@ -360,7 +381,7 @@ class ProcessingStep(Step):
         code: str = None,
         property_files: List[PropertyFile] = None,
         cache_config: CacheConfig = None,
-        depends_on: List[str] = None,
+        depends_on: Union[List[str], List[Step]] = None,
     ):
         """Construct a ProcessingStep, given a `Processor` instance.
 
@@ -381,8 +402,8 @@ class ProcessingStep(Step):
             property_files (List[PropertyFile]): A list of property files that workflow looks
                 for and resolves from the configured processing output list.
             cache_config (CacheConfig):  A `sagemaker.workflow.steps.CacheConfig` instance.
-            depends_on (List[str]): A list of step names this `sagemaker.workflow.steps.ProcessingStep`
-                depends on
+            depends_on (List[str] or List[Step]): A list of step names or step instance
+                this `sagemaker.workflow.steps.ProcessingStep` depends on
         """
         super(ProcessingStep, self).__init__(name, StepTypeEnum.PROCESSING, depends_on)
         self.processor = processor
@@ -450,7 +471,7 @@ class TuningStep(Step):
         inputs=None,
         job_arguments: List[str] = None,
         cache_config: CacheConfig = None,
-        depends_on: List[str] = None,
+        depends_on: Union[List[str], List[Step]] = None,
     ):
         """Construct a TuningStep, given a `HyperparameterTuner` instance.
 
@@ -490,8 +511,8 @@ class TuningStep(Step):
             job_arguments (List[str]): A list of strings to be passed into the processing job.
                 Defaults to `None`.
             cache_config (CacheConfig):  A `sagemaker.workflow.steps.CacheConfig` instance.
-            depends_on (List[str]): A list of step names this `sagemaker.workflow.steps.ProcessingStep`
-                depends on
+            depends_on (List[str] or List[Step]): A list of step names or step instance
+                this `sagemaker.workflow.steps.ProcessingStep` depends on
         """
         super(TuningStep, self).__init__(name, StepTypeEnum.TUNING, depends_on)
         self.tuner = tuner
@@ -544,7 +565,7 @@ class TuningStep(Step):
 
         return request_dict
 
-    def get_top_model_s3_uri(self, top_k: int, s3_bucket: str, prefix: str = ""):
+    def get_top_model_s3_uri(self, top_k: int, s3_bucket: str, prefix: str = "") -> Join:
         """Get the model artifact s3 uri from the top performing training jobs.
 
         Args:
